#!/usr/bin/perl
#
# Copyright (C) 2023 Juan Domingo (Juan.Domingo@uv.es)
#
# This script is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

use strict;
use warnings;

# CHANGE: modify this variables to 0 (false) or 1 (true) to get the desired look for your table
my $left_vertical_border=0;
my $intercolumn_vertical_border=1;
my $rigth_vertical_border=0;
my $horizontal_line_behind_header=1;
# and modify this variable for l, r or c columns
my $horizontal_alignment="l";

my $starttab = "\\begin{tabular}{";
if ($left_vertical_border)
{
 $starttab = $starttab."|";
}

my $interfield = $horizontal_alignment;
if ($intercolumn_vertical_border)
{
 $interfield = $interfield."|";
}

my $endtab = $horizontal_alignment;
if ($rigth_vertical_border)
{
 $endtab = $endtab."|} ";
}
else
{
 $endtab = $endtab."} ";
}

if ($horizontal_line_behind_header)
{
 $endtab = $endtab."\\hline ";
}
$endtab = $endtab."\\\\\n";

sub num_fields
{
 my $l=shift;
 my $lbars = $l;
 $lbars =~ s/[^\|]//g;
 my $nf=length($lbars)-1;
 if ($nf<1)
 {
  die("Error: the first line does not seem to be a header line.\n");
 }
 return $nf;
}

sub get_values
{
 my $l=shift;
 my $nf=shift;
 my $lnum=shift;
 my $f;
 my @val;
 while ($l =~ /\|([^\|]+)(.*)/)
 {
  $f=$1;
  $l=$2;
  $f =~ s/^\s+|\s+$//g;
  $f =~ s/\&/\\\&/g;
  push(@val,$f);
 }
 if (scalar(@val) != $nf)
 {
  die("Error in line $lnum of .csv: it does not look like a header or data line.");
 }
 return(@val);
}

my $line=<>;
chomp($line);
my $nfields=num_fields($line);

print $starttab;
my $nf;
for $nf(0..$nfields-2)
{
 print $interfield;
}
print $endtab;

my @values;
my $i=2;
while (defined($line=<>))
{
 chomp($line);
 if ($line =~ /^\+/)
 {
  if ($i>2)
  {
   print "\\end{tabular}\n";
   exit(0);
  }
 }
 else
 {
  @values = get_values($line,$nfields,$i);
  foreach my $nf(0..$nfields-2)
  {
   print "$values[$nf] & ";
  }
  print $values[$nfields-1]." \\\\\n";
 }
 $i++;
}

 
