#!/usr/bin/perl
#
# Copyright (C) 2023 Juan Domingo (Juan.Domingo@uv.es)
#
# This script is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

use strict;
use warnings;
use Algorithm::Combinatorics qw(combinations);;

($#ARGV == -1) || die("Usage: $0 (this program does not take arguments, it just generates the FillTherapy.sql file)\n");

# There are currently six possible therapies, that can be applied sepparately or in combination
# Currently, combinations seem to be of up to three therapies, but we will not restrict other possibilities, so
# all possible combinations (which are 2^6) will be generated.

my @therapies=("chemotherapy","radiotherapy","targeted therapy","immunotherapy","surgery","hormonal");


my $i;
my $iter;
my @s;

open(T,">therapy_test.txt");

open(G,">FillTherapy.sql");
print G "INSERT INTO Therapy VALUES('none');\n";
print T "'none'\n";

foreach my $item(@therapies)
{
 print G "INSERT INTO Therapy VALUES('$item');\n";
 print T "'$item'\n";
}

for $i(2..$#therapies+1)
{
 $iter = combinations(\@therapies,$i);

 while (my $c = $iter->next)
 {
  @s=sort(@$c);
  print G "INSERT INTO Therapy VALUES('";
  print T "'";
  foreach my $j(0..$#s-1)
  {
   print G "$s[$j]+";
   print T "$s[$j]+"
  }
  print G "$s[-1]');\n";
  print T "$s[-1]'\n";
 }
}

close(G);
close(T);

