#!/bin/bash
#
# Copyright (C) 2023 Juan Domingo (Juan.Domingo@uv.es)
#
# This script is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

# Script to recreate everything from the beginning, except the creation of the database with mariadb and activation of the service
# It need the presence of some directories and files:
# In this directory:
#	Correct_table.pl: to correct a small error in the DBOnco.sql as created by gerwin/ferret.
#	DB2drop.pl: to generate the SQL macro dropall.sql to drop all the tables from the database using the DBOnco.sql creation script
# In subdirectory BASIC_SQL:
#	DBOnco.sql: SQL script with creation of tables, as generated by gerwin/ferret.
#	doall.sql: SQL script to populate the tables.
#       delete_all_studies.sql: SQL script to delete the content of the tables loaded from papers, keeping the static information.
# In subdirectory EXTRACT:
#	FillTables.R: R script with functions to fill the tables related with genes. REMEMBER TO HAVE INSTALLED R and the packages listed in dogenetables.R
#	dogenetables.R: R script that calls the functions in FillTables.R and really generate the SQL scripts.
#	dogenetables.sh: bash script to call R, make it generate the SQL scripts and move them to our work folder.
# In subdirectory GENSQL:
#	FillDrug.pl and ATCsimp.csv: script and data to generate the drug filling SQL script FillDrug.sql
#	FillPathology.pl and icd10cm_order_2021.txt: script and data to generate the pathology filling script FillPathology.sql
#	FillTherapy.pl: script to generate the therapy filling script FillTherapy.sql. No data, therapy names are written into the script.
#	FillVariationType.pl: script to generate the variation types filling script FillVariationType.sql. No data, variation types are written into the script.
#	dotables.sh: bash script to call all the Perl scripts, make it generate the SQL scripts and move them to our work folder.
# In subdirectory FILL_FROM_CSV
#	fields.csv: a CSV file with one column containing the names of the valid fileds to be found in the data. Just for check.
#	data.csv: the data themselves extracted manually from the publications.
#	FillFromPapers.pl: the Perl macro to parse data.csv and generate the SQL scripts to populate the DB.
#	fillfrompapers.sh: bash script to call the former Perl script and move the generated SQL scripts to our work folder.

rm -f *.sql

./CorrectTable.pl BASIC_SQL/DBOnco.sql

if [ $? -ne 0 ]; then
 echo "Error in perl macro CorrectTable.pl"
 exit 1
fi

./DB2drop.pl DBOnco.sql
if [ $? -ne 0 ]; then
 echo "Error in perl macro DB2drop.pl"
 exit 1
fi

cp BASIC_SQL/doall.sql .
cp BASIC_SQL/delete_all_studies.sql .

cd EXTRACT
./dogenetables.sh
if [ $? -ne 0 ]; then
 exit 1
fi
cd ..

cd GENSQL
./dotables.sh
if [ $? -ne 0 ]; then
 exit 1
fi
cd ..

cd FILL_FROM_CSV
./fillfrompapers.sh
if [ $? -ne 0 ]; then
 exit 1
fi
cd ..

# After that, you should go into the database with 
# mysql --silent -u oncocardio -p oncocardio
# and execute
#
# source doall.sql;
# source fill_all_studies.sql;
#
# If, later on, you want to keep the static tables and fill only the variable part (studies), just do
#
# source delete_all_studies.sql;
# source fill_all_studies.sql;


